% Quokka3 settingsfile to showcase biTLM method
% 2D structure (stripe cut from cell)
% (c) 2021 Andreas Fell

% sample properties and experimental details given in:
% A. Fell et al., "Why and How to Measure the Non-Metallized Contact Resistivity of a Passivating Contact," 2020 47th IEEE Photovoltaic Specialists Conference (PVSC), Calgary, OR, 2020, pp. 0884-0889, doi: 10.1109/PVSC45281.2020.9301007
%
% The results differ from the ones in the publication mainly due to co-fitting the rear-side properties linked the front side ones, a feature not yet avaibable during rendering the results in the paper
% Also as written in the paper, there are some imperfections in this early experiment, so the results are not reliable and sensitive to the fit settings
% Still, these settings show how the biTLM method works, the robustness dependens on the quality of the experimental data

Syntax = 'generic';

Sweep.Enable = 1;
Sweep.NGroups = 2;
Sweep.GroupA(1).Parameter = 'PadFeature(2).Geometry.PositionX';
Sweep.GroupA(1).Values = [6000 7500 9000 10500 12000];
Sweep.GroupB(1).Parameter = 'MetalFeature(2).Electrical.Rsheet';
Sweep.GroupB(1).Values = [1e10 0.003]; % a very high Rsheet of the rear metal represents the case without rear metallization

Optim.Enable = 1;
Optim.Variable(1).Parameter = 'SkinFeature(1).Lumped.Electrical.VerticalResistivity.OhmicResistivity'; % non-metallized rho_skin
Optim.Variable(1).Guess = 0.1;
Optim.Variable(1).UpperBound = 0.2;
Optim.Variable(1).LowerBound = 0.01;
Optim.Variable(2).Parameter = 'SkinFeature(2).Lumped.Electrical.VerticalResistivity.OhmicResistivity'; % metallized rho_skin
Optim.Variable(2).Link(1).Parameter = 'SkinFeature(10).Lumped.Electrical.VerticalResistivity.OhmicResistivity'; % metallized rho_skin at rear side is identical to the front side
Optim.Variable(2).Guess = 0.02;
Optim.Variable(2).UpperBound = 0.2;
Optim.Variable(2).LowerBound = 0.001;
Optim.Variable(3).Parameter = 'SkinFeature(1).Lumped.Electrical.Rsheet';
Optim.Variable(3).Link(1).Parameter = 'SkinFeature(2).Lumped.Electrical.Rsheet'; % metallized Rsheet is identical to non-metallized Rsheet
Optim.Variable(3).Link(2).Parameter = 'SkinFeature(10).Lumped.Electrical.Rsheet'; % rear side Rsheet is identical to front side Rsheet
Optim.Variable(3).Guess = 85;
Optim.Variable(3).UpperBound = 120;
Optim.Variable(3).LowerBound = 50;
Optim.Variable(4).Parameter = 'ContactFeature(1).OhmicResistivity';
Optim.Variable(4).Link(1).Parameter = 'ContactFeature(2).OhmicResistivity';
Optim.Variable(4).Guess = 1e-4;
Optim.Variable(4).UpperBound = 1e-2;
Optim.Variable(4).LowerBound = 1e-5;

Optim.Goal(1).Type = 'curve';
Optim.Goal(1).iSweepB = 2;
Optim.Goal(1).XResultName = 'sweep'; % means the X-value is set to the values of Sweep.GroupA(1)
Optim.Goal(1).YResultName = '/Scalars/Resistance';
Optim.Goal(1).Curve.Type = 'file';
Optim.Goal(1).Curve.File = 'Rmeas_rearmetal.txt'; % contains the measured resistances as a function of 'PadFeature(2).Geometry.PositionX', i.e. the distance between the measured pads in the measurement plus the position of the first pad
Optim.Goal(2).Type = 'curve';
Optim.Goal(2).iSweepB = 1;
Optim.Goal(2).XResultName = 'sweep';
Optim.Goal(2).YResultName = '/Scalars/Resistance';
Optim.Goal(2).Curve.Type = 'file';
Optim.Goal(2).Curve.File = 'Rmeas_norearmetal.txt';


Domain.DeviceType = 'resistive device';
Domain.Dimensions = 2;
Domain.Wz = 155;
Domain.Wx = 18000;

Solver.SolutionType = 'Resistance';
Solver.Electrical.MetalModelType = 'finite-differences';

Bulk.BackgroundDoping.Resistivity = 4;

SkinFeature(1).Name = 'front poly';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).Geometry.Shape = 'full';
SkinFeature(1).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(1).Lumped.Electrical.Rsheet = 84.3;
SkinFeature(1).Lumped.Electrical.VerticalResistivityEnable = 1;
SkinFeature(1).Lumped.Electrical.VerticalResistivity.OhmicResistivity = 0.6; % non-metallized rho_skin

SkinFeature(2).Name = 'front poly - contact';
SkinFeature(2).Geometry.Plane = 'front';
SkinFeature(2).Geometry.Shape = 'rectangle';
SkinFeature(2).Geometry.SizeX = 46;
SkinFeature(2).Geometry.PositionX = 0;
SkinFeature(2).Geometry.PitchX = 1500;
SkinFeature(2).Geometry.RepetitionsX = 13;
SkinFeature(2).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(2).Lumped.Electrical.Rsheet = 85;
SkinFeature(2).Lumped.Electrical.VerticalResistivityEnable = 1;
SkinFeature(2).Lumped.Electrical.VerticalResistivity.OhmicResistivity = 0.01; % metallized rho_skin

SkinFeature(10).Name = 'rear poly';
SkinFeature(10).Geometry.Plane = 'rear';
SkinFeature(10).Geometry.Shape = 'full';
SkinFeature(10).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(10).Lumped.Electrical.Rsheet = 85;
SkinFeature(10).Lumped.Electrical.VerticalResistivityEnable = 1;
SkinFeature(10).Lumped.Electrical.VerticalResistivity.OhmicResistivity = 0.01; % metallized rho_skin

ContactFeature(1).Name = 'front contacts';
ContactFeature(1).Geometry.Plane = 'front';
ContactFeature(1).Geometry.Shape = 'rectangle';
ContactFeature(1).Geometry.SizeX = 46;
ContactFeature(1).Geometry.PositionX = 0;
ContactFeature(1).Geometry.PitchX = 1500;
ContactFeature(1).Geometry.RepetitionsX = 13;
ContactFeature(1).OhmicResistivity = 1e-5;

ContactFeature(2).Name = 'rear contact';
ContactFeature(2).Geometry.Plane = 'rear';
ContactFeature(2).Geometry.Shape = 'full';
ContactFeature(2).OhmicResistivity = 1e-5; % assuming a perfect rear metallization

MetalFeature(1).Name = 'front fingers';
MetalFeature(1).Geometry.Plane = 'front';
MetalFeature(1).Geometry.Shape = 'rectangle';
MetalFeature(1).Geometry.SizeX = 46;
MetalFeature(1).Geometry.PositionX = 0;
MetalFeature(1).Geometry.PitchX = 1500;
MetalFeature(1).Geometry.RepetitionsX = 13;
MetalFeature(1).Electrical.Rsheet = 0.003;

MetalFeature(2).Name = 'rear metal';
MetalFeature(2).Geometry.Plane = 'rear';
MetalFeature(2).Geometry.Shape = 'full';
MetalFeature(2).Electrical.Rsheet = 0.003;

PadFeature(1).Name = 'left probe';
PadFeature(1).Geometry.Plane = 'front';
PadFeature(1).Geometry.Shape = 'rectangle';
PadFeature(1).Geometry.PositionX = 4500;
PadFeature(1).Geometry.SizeX = 46;
PadFeature(1).Electrical.ContactResistivity = 1e-6;
PadFeature(1).Electrical.Polarity = 'n-type';

PadFeature(2).Name = 'right probe';
PadFeature(2).Geometry.Plane = 'front';
PadFeature(2).Geometry.Shape = 'rectangle';
PadFeature(2).Geometry.PositionX = 13500;
PadFeature(2).Geometry.SizeX = 46;
PadFeature(2).Electrical.ContactResistivity = 1e-6;
PadFeature(2).Electrical.Polarity = 'p-type';
